# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SnmpTrapsArgs', 'SnmpTraps']

@pulumi.input_type
class SnmpTrapsArgs:
    def __init__(__self__, *,
                 auth_passwordencrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 community: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[_builtins.str]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy_password: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_password_encrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 security_level: Optional[pulumi.Input[_builtins.str]] = None,
                 security_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SnmpTraps resource.
        :param pulumi.Input[_builtins.str] auth_passwordencrypted: Encrypted password
        :param pulumi.Input[_builtins.str] auth_protocol: Specifies the protocol used to authenticate the user.
        :param pulumi.Input[_builtins.str] community: Specifies the community string used for this trap.
        :param pulumi.Input[_builtins.str] description: The port that the trap will be sent to.
        :param pulumi.Input[_builtins.str] engine_id: Specifies the authoritative security engine for SNMPv3.
        :param pulumi.Input[_builtins.str] host: The host the trap will be sent to.
        :param pulumi.Input[_builtins.str] name: Name of the snmp trap.
        :param pulumi.Input[_builtins.int] port: User defined description.
        :param pulumi.Input[_builtins.str] privacy_password: Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        :param pulumi.Input[_builtins.str] privacy_password_encrypted: Specifies the encrypted password used to encrypt traffic.
        :param pulumi.Input[_builtins.str] privacy_protocol: Specifies the protocol used to encrypt traffic.
        :param pulumi.Input[_builtins.str] security_level: Specifies whether or not traffic is encrypted and whether or not authentication is required.
        :param pulumi.Input[_builtins.str] security_name: Security name used in conjunction with SNMPv3.
        :param pulumi.Input[_builtins.str] version: SNMP version used for sending the trap.
        """
        if auth_passwordencrypted is not None:
            pulumi.set(__self__, "auth_passwordencrypted", auth_passwordencrypted)
        if auth_protocol is not None:
            pulumi.set(__self__, "auth_protocol", auth_protocol)
        if community is not None:
            pulumi.set(__self__, "community", community)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if engine_id is not None:
            pulumi.set(__self__, "engine_id", engine_id)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if privacy_password is not None:
            pulumi.set(__self__, "privacy_password", privacy_password)
        if privacy_password_encrypted is not None:
            pulumi.set(__self__, "privacy_password_encrypted", privacy_password_encrypted)
        if privacy_protocol is not None:
            pulumi.set(__self__, "privacy_protocol", privacy_protocol)
        if security_level is not None:
            pulumi.set(__self__, "security_level", security_level)
        if security_name is not None:
            pulumi.set(__self__, "security_name", security_name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="authPasswordencrypted")
    def auth_passwordencrypted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Encrypted password
        """
        return pulumi.get(self, "auth_passwordencrypted")

    @auth_passwordencrypted.setter
    def auth_passwordencrypted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_passwordencrypted", value)

    @_builtins.property
    @pulumi.getter(name="authProtocol")
    def auth_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the protocol used to authenticate the user.
        """
        return pulumi.get(self, "auth_protocol")

    @auth_protocol.setter
    def auth_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_protocol", value)

    @_builtins.property
    @pulumi.getter
    def community(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the community string used for this trap.
        """
        return pulumi.get(self, "community")

    @community.setter
    def community(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "community", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The port that the trap will be sent to.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the authoritative security engine for SNMPv3.
        """
        return pulumi.get(self, "engine_id")

    @engine_id.setter
    def engine_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "engine_id", value)

    @_builtins.property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The host the trap will be sent to.
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the snmp trap.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        User defined description.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="privacyPassword")
    def privacy_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        """
        return pulumi.get(self, "privacy_password")

    @privacy_password.setter
    def privacy_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy_password", value)

    @_builtins.property
    @pulumi.getter(name="privacyPasswordEncrypted")
    def privacy_password_encrypted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the encrypted password used to encrypt traffic.
        """
        return pulumi.get(self, "privacy_password_encrypted")

    @privacy_password_encrypted.setter
    def privacy_password_encrypted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy_password_encrypted", value)

    @_builtins.property
    @pulumi.getter(name="privacyProtocol")
    def privacy_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the protocol used to encrypt traffic.
        """
        return pulumi.get(self, "privacy_protocol")

    @privacy_protocol.setter
    def privacy_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy_protocol", value)

    @_builtins.property
    @pulumi.getter(name="securityLevel")
    def security_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether or not traffic is encrypted and whether or not authentication is required.
        """
        return pulumi.get(self, "security_level")

    @security_level.setter
    def security_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "security_level", value)

    @_builtins.property
    @pulumi.getter(name="securityName")
    def security_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Security name used in conjunction with SNMPv3.
        """
        return pulumi.get(self, "security_name")

    @security_name.setter
    def security_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "security_name", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SNMP version used for sending the trap.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _SnmpTrapsState:
    def __init__(__self__, *,
                 auth_passwordencrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 community: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[_builtins.str]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy_password: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_password_encrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 security_level: Optional[pulumi.Input[_builtins.str]] = None,
                 security_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SnmpTraps resources.
        :param pulumi.Input[_builtins.str] auth_passwordencrypted: Encrypted password
        :param pulumi.Input[_builtins.str] auth_protocol: Specifies the protocol used to authenticate the user.
        :param pulumi.Input[_builtins.str] community: Specifies the community string used for this trap.
        :param pulumi.Input[_builtins.str] description: The port that the trap will be sent to.
        :param pulumi.Input[_builtins.str] engine_id: Specifies the authoritative security engine for SNMPv3.
        :param pulumi.Input[_builtins.str] host: The host the trap will be sent to.
        :param pulumi.Input[_builtins.str] name: Name of the snmp trap.
        :param pulumi.Input[_builtins.int] port: User defined description.
        :param pulumi.Input[_builtins.str] privacy_password: Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        :param pulumi.Input[_builtins.str] privacy_password_encrypted: Specifies the encrypted password used to encrypt traffic.
        :param pulumi.Input[_builtins.str] privacy_protocol: Specifies the protocol used to encrypt traffic.
        :param pulumi.Input[_builtins.str] security_level: Specifies whether or not traffic is encrypted and whether or not authentication is required.
        :param pulumi.Input[_builtins.str] security_name: Security name used in conjunction with SNMPv3.
        :param pulumi.Input[_builtins.str] version: SNMP version used for sending the trap.
        """
        if auth_passwordencrypted is not None:
            pulumi.set(__self__, "auth_passwordencrypted", auth_passwordencrypted)
        if auth_protocol is not None:
            pulumi.set(__self__, "auth_protocol", auth_protocol)
        if community is not None:
            pulumi.set(__self__, "community", community)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if engine_id is not None:
            pulumi.set(__self__, "engine_id", engine_id)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if privacy_password is not None:
            pulumi.set(__self__, "privacy_password", privacy_password)
        if privacy_password_encrypted is not None:
            pulumi.set(__self__, "privacy_password_encrypted", privacy_password_encrypted)
        if privacy_protocol is not None:
            pulumi.set(__self__, "privacy_protocol", privacy_protocol)
        if security_level is not None:
            pulumi.set(__self__, "security_level", security_level)
        if security_name is not None:
            pulumi.set(__self__, "security_name", security_name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="authPasswordencrypted")
    def auth_passwordencrypted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Encrypted password
        """
        return pulumi.get(self, "auth_passwordencrypted")

    @auth_passwordencrypted.setter
    def auth_passwordencrypted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_passwordencrypted", value)

    @_builtins.property
    @pulumi.getter(name="authProtocol")
    def auth_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the protocol used to authenticate the user.
        """
        return pulumi.get(self, "auth_protocol")

    @auth_protocol.setter
    def auth_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_protocol", value)

    @_builtins.property
    @pulumi.getter
    def community(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the community string used for this trap.
        """
        return pulumi.get(self, "community")

    @community.setter
    def community(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "community", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The port that the trap will be sent to.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the authoritative security engine for SNMPv3.
        """
        return pulumi.get(self, "engine_id")

    @engine_id.setter
    def engine_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "engine_id", value)

    @_builtins.property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The host the trap will be sent to.
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the snmp trap.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        User defined description.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="privacyPassword")
    def privacy_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        """
        return pulumi.get(self, "privacy_password")

    @privacy_password.setter
    def privacy_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy_password", value)

    @_builtins.property
    @pulumi.getter(name="privacyPasswordEncrypted")
    def privacy_password_encrypted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the encrypted password used to encrypt traffic.
        """
        return pulumi.get(self, "privacy_password_encrypted")

    @privacy_password_encrypted.setter
    def privacy_password_encrypted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy_password_encrypted", value)

    @_builtins.property
    @pulumi.getter(name="privacyProtocol")
    def privacy_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the protocol used to encrypt traffic.
        """
        return pulumi.get(self, "privacy_protocol")

    @privacy_protocol.setter
    def privacy_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy_protocol", value)

    @_builtins.property
    @pulumi.getter(name="securityLevel")
    def security_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether or not traffic is encrypted and whether or not authentication is required.
        """
        return pulumi.get(self, "security_level")

    @security_level.setter
    def security_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "security_level", value)

    @_builtins.property
    @pulumi.getter(name="securityName")
    def security_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Security name used in conjunction with SNMPv3.
        """
        return pulumi.get(self, "security_name")

    @security_name.setter
    def security_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "security_name", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SNMP version used for sending the trap.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("f5bigip:sys/snmpTraps:SnmpTraps")
class SnmpTraps(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_passwordencrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 community: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[_builtins.str]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy_password: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_password_encrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 security_level: Optional[pulumi.Input[_builtins.str]] = None,
                 security_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `sys.SnmpTraps` provides details bout how to enable snmp_traps resource on BIG-IP
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        snmp_traps = f5bigip.sys.SnmpTraps("snmp_traps",
            name="snmptraps",
            community="f5community",
            host="195.10.10.1",
            description="Setup snmp traps",
            port=111)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_passwordencrypted: Encrypted password
        :param pulumi.Input[_builtins.str] auth_protocol: Specifies the protocol used to authenticate the user.
        :param pulumi.Input[_builtins.str] community: Specifies the community string used for this trap.
        :param pulumi.Input[_builtins.str] description: The port that the trap will be sent to.
        :param pulumi.Input[_builtins.str] engine_id: Specifies the authoritative security engine for SNMPv3.
        :param pulumi.Input[_builtins.str] host: The host the trap will be sent to.
        :param pulumi.Input[_builtins.str] name: Name of the snmp trap.
        :param pulumi.Input[_builtins.int] port: User defined description.
        :param pulumi.Input[_builtins.str] privacy_password: Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        :param pulumi.Input[_builtins.str] privacy_password_encrypted: Specifies the encrypted password used to encrypt traffic.
        :param pulumi.Input[_builtins.str] privacy_protocol: Specifies the protocol used to encrypt traffic.
        :param pulumi.Input[_builtins.str] security_level: Specifies whether or not traffic is encrypted and whether or not authentication is required.
        :param pulumi.Input[_builtins.str] security_name: Security name used in conjunction with SNMPv3.
        :param pulumi.Input[_builtins.str] version: SNMP version used for sending the trap.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SnmpTrapsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `sys.SnmpTraps` provides details bout how to enable snmp_traps resource on BIG-IP
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        snmp_traps = f5bigip.sys.SnmpTraps("snmp_traps",
            name="snmptraps",
            community="f5community",
            host="195.10.10.1",
            description="Setup snmp traps",
            port=111)
        ```

        :param str resource_name: The name of the resource.
        :param SnmpTrapsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SnmpTrapsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_passwordencrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 community: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[_builtins.str]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy_password: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_password_encrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 privacy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 security_level: Optional[pulumi.Input[_builtins.str]] = None,
                 security_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SnmpTrapsArgs.__new__(SnmpTrapsArgs)

            __props__.__dict__["auth_passwordencrypted"] = auth_passwordencrypted
            __props__.__dict__["auth_protocol"] = auth_protocol
            __props__.__dict__["community"] = community
            __props__.__dict__["description"] = description
            __props__.__dict__["engine_id"] = engine_id
            __props__.__dict__["host"] = host
            __props__.__dict__["name"] = name
            __props__.__dict__["port"] = port
            __props__.__dict__["privacy_password"] = privacy_password
            __props__.__dict__["privacy_password_encrypted"] = privacy_password_encrypted
            __props__.__dict__["privacy_protocol"] = privacy_protocol
            __props__.__dict__["security_level"] = security_level
            __props__.__dict__["security_name"] = security_name
            __props__.__dict__["version"] = version
        super(SnmpTraps, __self__).__init__(
            'f5bigip:sys/snmpTraps:SnmpTraps',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_passwordencrypted: Optional[pulumi.Input[_builtins.str]] = None,
            auth_protocol: Optional[pulumi.Input[_builtins.str]] = None,
            community: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            engine_id: Optional[pulumi.Input[_builtins.str]] = None,
            host: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            privacy_password: Optional[pulumi.Input[_builtins.str]] = None,
            privacy_password_encrypted: Optional[pulumi.Input[_builtins.str]] = None,
            privacy_protocol: Optional[pulumi.Input[_builtins.str]] = None,
            security_level: Optional[pulumi.Input[_builtins.str]] = None,
            security_name: Optional[pulumi.Input[_builtins.str]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None) -> 'SnmpTraps':
        """
        Get an existing SnmpTraps resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_passwordencrypted: Encrypted password
        :param pulumi.Input[_builtins.str] auth_protocol: Specifies the protocol used to authenticate the user.
        :param pulumi.Input[_builtins.str] community: Specifies the community string used for this trap.
        :param pulumi.Input[_builtins.str] description: The port that the trap will be sent to.
        :param pulumi.Input[_builtins.str] engine_id: Specifies the authoritative security engine for SNMPv3.
        :param pulumi.Input[_builtins.str] host: The host the trap will be sent to.
        :param pulumi.Input[_builtins.str] name: Name of the snmp trap.
        :param pulumi.Input[_builtins.int] port: User defined description.
        :param pulumi.Input[_builtins.str] privacy_password: Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        :param pulumi.Input[_builtins.str] privacy_password_encrypted: Specifies the encrypted password used to encrypt traffic.
        :param pulumi.Input[_builtins.str] privacy_protocol: Specifies the protocol used to encrypt traffic.
        :param pulumi.Input[_builtins.str] security_level: Specifies whether or not traffic is encrypted and whether or not authentication is required.
        :param pulumi.Input[_builtins.str] security_name: Security name used in conjunction with SNMPv3.
        :param pulumi.Input[_builtins.str] version: SNMP version used for sending the trap.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SnmpTrapsState.__new__(_SnmpTrapsState)

        __props__.__dict__["auth_passwordencrypted"] = auth_passwordencrypted
        __props__.__dict__["auth_protocol"] = auth_protocol
        __props__.__dict__["community"] = community
        __props__.__dict__["description"] = description
        __props__.__dict__["engine_id"] = engine_id
        __props__.__dict__["host"] = host
        __props__.__dict__["name"] = name
        __props__.__dict__["port"] = port
        __props__.__dict__["privacy_password"] = privacy_password
        __props__.__dict__["privacy_password_encrypted"] = privacy_password_encrypted
        __props__.__dict__["privacy_protocol"] = privacy_protocol
        __props__.__dict__["security_level"] = security_level
        __props__.__dict__["security_name"] = security_name
        __props__.__dict__["version"] = version
        return SnmpTraps(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authPasswordencrypted")
    def auth_passwordencrypted(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Encrypted password
        """
        return pulumi.get(self, "auth_passwordencrypted")

    @_builtins.property
    @pulumi.getter(name="authProtocol")
    def auth_protocol(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the protocol used to authenticate the user.
        """
        return pulumi.get(self, "auth_protocol")

    @_builtins.property
    @pulumi.getter
    def community(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the community string used for this trap.
        """
        return pulumi.get(self, "community")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The port that the trap will be sent to.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the authoritative security engine for SNMPv3.
        """
        return pulumi.get(self, "engine_id")

    @_builtins.property
    @pulumi.getter
    def host(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The host the trap will be sent to.
        """
        return pulumi.get(self, "host")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the snmp trap.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        User defined description.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="privacyPassword")
    def privacy_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the clear text password used to encrypt traffic. This field will not be displayed.
        """
        return pulumi.get(self, "privacy_password")

    @_builtins.property
    @pulumi.getter(name="privacyPasswordEncrypted")
    def privacy_password_encrypted(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the encrypted password used to encrypt traffic.
        """
        return pulumi.get(self, "privacy_password_encrypted")

    @_builtins.property
    @pulumi.getter(name="privacyProtocol")
    def privacy_protocol(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the protocol used to encrypt traffic.
        """
        return pulumi.get(self, "privacy_protocol")

    @_builtins.property
    @pulumi.getter(name="securityLevel")
    def security_level(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies whether or not traffic is encrypted and whether or not authentication is required.
        """
        return pulumi.get(self, "security_level")

    @_builtins.property
    @pulumi.getter(name="securityName")
    def security_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Security name used in conjunction with SNMPv3.
        """
        return pulumi.get(self, "security_name")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        SNMP version used for sending the trap.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('f5bigip')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def address(self) -> Optional[str]:
        """
        Domain name/IP of the BigIP
        """
        return __config__.get('address')

    @_builtins.property
    def api_retries(self) -> Optional[int]:
        """
        Amount of times to retry AS3 API requests. Default: 10.
        """
        return __config__.get_int('apiRetries')

    @_builtins.property
    def api_timeout(self) -> Optional[int]:
        """
        A timeout for AS3 requests, represented as a number of seconds. Default: 60
        """
        return __config__.get_int('apiTimeout')

    @_builtins.property
    def login_ref(self) -> Optional[str]:
        """
        Login reference for token authentication (see BIG-IP REST docs for details)
        """
        return __config__.get('loginRef')

    @_builtins.property
    def password(self) -> Optional[str]:
        """
        The user's password. Leave empty if using token_value
        """
        return __config__.get('password')

    @_builtins.property
    def port(self) -> Optional[str]:
        """
        Management Port to connect to Bigip
        """
        return __config__.get('port')

    @_builtins.property
    def teem_disable(self) -> Optional[bool]:
        """
        If this flag set to true,sending telemetry data to TEEM will be disabled
        """
        return __config__.get_bool('teemDisable')

    @_builtins.property
    def token_auth(self) -> Optional[bool]:
        """
        Enable to use token authentication. Can be set via the BIGIP_TOKEN_AUTH environment variable
        """
        return __config__.get_bool('tokenAuth')

    @_builtins.property
    def token_timeout(self) -> Optional[int]:
        """
        A lifespan to request for the AS3 auth token, represented as a number of seconds. Default: 1200
        """
        return __config__.get_int('tokenTimeout')

    @_builtins.property
    def token_value(self) -> Optional[str]:
        """
        A token generated outside the provider, in place of password
        """
        return __config__.get('tokenValue')

    @_builtins.property
    def trusted_cert_path(self) -> Optional[str]:
        """
        Valid Trusted Certificate path
        """
        return __config__.get('trustedCertPath')

    @_builtins.property
    def username(self) -> Optional[str]:
        """
        Username with API access to the BigIP
        """
        return __config__.get('username')

    @_builtins.property
    def validate_certs_disable(self) -> Optional[bool]:
        """
        If set to true, Disables TLS certificate check on BIG-IP. Default : True
        """
        return __config__.get_bool('validateCertsDisable')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProfileRewriteUriRulesArgs', 'ProfileRewriteUriRules']

@pulumi.input_type
class ProfileRewriteUriRulesArgs:
    def __init__(__self__, *,
                 clients: pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]],
                 profile_name: pulumi.Input[_builtins.str],
                 rule_name: pulumi.Input[_builtins.str],
                 servers: pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]],
                 rule_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProfileRewriteUriRules resource.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]] clients: Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] profile_name: Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        :param pulumi.Input[_builtins.str] rule_name: Specifies the name of the uri rule.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]] servers: Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] rule_type: Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        """
        pulumi.set(__self__, "clients", clients)
        pulumi.set(__self__, "profile_name", profile_name)
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "servers", servers)
        if rule_type is not None:
            pulumi.set(__self__, "rule_type", rule_type)

    @_builtins.property
    @pulumi.getter
    def clients(self) -> pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "clients")

    @clients.setter
    def clients(self, value: pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]]):
        pulumi.set(self, "clients", value)

    @_builtins.property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        """
        return pulumi.get(self, "profile_name")

    @profile_name.setter
    def profile_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "profile_name", value)

    @_builtins.property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the name of the uri rule.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rule_name", value)

    @_builtins.property
    @pulumi.getter
    def servers(self) -> pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]]):
        pulumi.set(self, "servers", value)

    @_builtins.property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_type", value)


@pulumi.input_type
class _ProfileRewriteUriRulesState:
    def __init__(__self__, *,
                 clients: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[_builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]]] = None):
        """
        Input properties used for looking up and filtering ProfileRewriteUriRules resources.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]] clients: Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] profile_name: Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        :param pulumi.Input[_builtins.str] rule_name: Specifies the name of the uri rule.
        :param pulumi.Input[_builtins.str] rule_type: Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]] servers: Block type. Each request is block type with following arguments.
        """
        if clients is not None:
            pulumi.set(__self__, "clients", clients)
        if profile_name is not None:
            pulumi.set(__self__, "profile_name", profile_name)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_type is not None:
            pulumi.set(__self__, "rule_type", rule_type)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)

    @_builtins.property
    @pulumi.getter
    def clients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "clients")

    @clients.setter
    def clients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesClientArgs']]]]):
        pulumi.set(self, "clients", value)

    @_builtins.property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        """
        return pulumi.get(self, "profile_name")

    @profile_name.setter
    def profile_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile_name", value)

    @_builtins.property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the uri rule.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @_builtins.property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_type", value)

    @_builtins.property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteUriRulesServerArgs']]]]):
        pulumi.set(self, "servers", value)


@pulumi.type_token("f5bigip:ltm/profileRewriteUriRules:ProfileRewriteUriRules")
class ProfileRewriteUriRules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 clients: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesClientArgs', 'ProfileRewriteUriRulesClientArgsDict']]]]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[_builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesServerArgs', 'ProfileRewriteUriRulesServerArgsDict']]]]] = None,
                 __props__=None):
        """
        `ltm.ProfileRewriteUriRules` Configures uri rewrite rules attached to the ltm rewrite profile

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        tftest = f5bigip.ltm.ProfileRewrite("tftest",
            name="/Common/tf_profile",
            defaults_from="/Common/rewrite",
            rewrite_mode="uri-translation")
        tftestrule1 = f5bigip.ltm.ProfileRewriteUriRules("tftestrule1",
            profile_name=tftest.name,
            rule_name="tf_rule",
            rule_type="request",
            clients=[{
                "host": "www.foo.com",
                "scheme": "https",
            }],
            servers=[{
                "host": "www.bar.com",
                "path": "/this/",
                "scheme": "https",
                "port": "8888",
            }])
        tftestrule2 = f5bigip.ltm.ProfileRewriteUriRules("tftestrule2",
            profile_name=tftest.name,
            rule_name="tf_rule2",
            clients=[{
                "host": "www.baz.com",
                "path": "/that/",
                "scheme": "ftp",
                "port": "8888",
            }],
            servers=[{
                "host": "www.buz.com",
                "path": "/those/",
                "scheme": "ftps",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesClientArgs', 'ProfileRewriteUriRulesClientArgsDict']]]] clients: Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] profile_name: Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        :param pulumi.Input[_builtins.str] rule_name: Specifies the name of the uri rule.
        :param pulumi.Input[_builtins.str] rule_type: Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesServerArgs', 'ProfileRewriteUriRulesServerArgsDict']]]] servers: Block type. Each request is block type with following arguments.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileRewriteUriRulesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileRewriteUriRules` Configures uri rewrite rules attached to the ltm rewrite profile

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        tftest = f5bigip.ltm.ProfileRewrite("tftest",
            name="/Common/tf_profile",
            defaults_from="/Common/rewrite",
            rewrite_mode="uri-translation")
        tftestrule1 = f5bigip.ltm.ProfileRewriteUriRules("tftestrule1",
            profile_name=tftest.name,
            rule_name="tf_rule",
            rule_type="request",
            clients=[{
                "host": "www.foo.com",
                "scheme": "https",
            }],
            servers=[{
                "host": "www.bar.com",
                "path": "/this/",
                "scheme": "https",
                "port": "8888",
            }])
        tftestrule2 = f5bigip.ltm.ProfileRewriteUriRules("tftestrule2",
            profile_name=tftest.name,
            rule_name="tf_rule2",
            clients=[{
                "host": "www.baz.com",
                "path": "/that/",
                "scheme": "ftp",
                "port": "8888",
            }],
            servers=[{
                "host": "www.buz.com",
                "path": "/those/",
                "scheme": "ftps",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param ProfileRewriteUriRulesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileRewriteUriRulesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 clients: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesClientArgs', 'ProfileRewriteUriRulesClientArgsDict']]]]] = None,
                 profile_name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[_builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesServerArgs', 'ProfileRewriteUriRulesServerArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileRewriteUriRulesArgs.__new__(ProfileRewriteUriRulesArgs)

            if clients is None and not opts.urn:
                raise TypeError("Missing required property 'clients'")
            __props__.__dict__["clients"] = clients
            if profile_name is None and not opts.urn:
                raise TypeError("Missing required property 'profile_name'")
            __props__.__dict__["profile_name"] = profile_name
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            __props__.__dict__["rule_type"] = rule_type
            if servers is None and not opts.urn:
                raise TypeError("Missing required property 'servers'")
            __props__.__dict__["servers"] = servers
        super(ProfileRewriteUriRules, __self__).__init__(
            'f5bigip:ltm/profileRewriteUriRules:ProfileRewriteUriRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            clients: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesClientArgs', 'ProfileRewriteUriRulesClientArgsDict']]]]] = None,
            profile_name: Optional[pulumi.Input[_builtins.str]] = None,
            rule_name: Optional[pulumi.Input[_builtins.str]] = None,
            rule_type: Optional[pulumi.Input[_builtins.str]] = None,
            servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesServerArgs', 'ProfileRewriteUriRulesServerArgsDict']]]]] = None) -> 'ProfileRewriteUriRules':
        """
        Get an existing ProfileRewriteUriRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesClientArgs', 'ProfileRewriteUriRulesClientArgsDict']]]] clients: Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] profile_name: Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        :param pulumi.Input[_builtins.str] rule_name: Specifies the name of the uri rule.
        :param pulumi.Input[_builtins.str] rule_type: Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteUriRulesServerArgs', 'ProfileRewriteUriRulesServerArgsDict']]]] servers: Block type. Each request is block type with following arguments.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileRewriteUriRulesState.__new__(_ProfileRewriteUriRulesState)

        __props__.__dict__["clients"] = clients
        __props__.__dict__["profile_name"] = profile_name
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["rule_type"] = rule_type
        __props__.__dict__["servers"] = servers
        return ProfileRewriteUriRules(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def clients(self) -> pulumi.Output[Sequence['outputs.ProfileRewriteUriRulesClient']]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "clients")

    @_builtins.property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the rewrite profile. ( policy name should be in full path which is combination of partition and policy name )
        """
        return pulumi.get(self, "profile_name")

    @_builtins.property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of the uri rule.
        """
        return pulumi.get(self, "rule_name")

    @_builtins.property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the type of the uri rule. Valid choices are: `request, response, both`. Default value is: `both`
        """
        return pulumi.get(self, "rule_type")

    @_builtins.property
    @pulumi.getter
    def servers(self) -> pulumi.Output[Sequence['outputs.ProfileRewriteUriRulesServer']]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "servers")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SelfIpArgs', 'SelfIp']

@pulumi.input_type
class SelfIpArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[_builtins.str],
                 name: pulumi.Input[_builtins.str],
                 vlan: pulumi.Input[_builtins.str],
                 port_lockdowns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SelfIp resource.
        :param pulumi.Input[_builtins.str] ip: The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        :param pulumi.Input[_builtins.str] name: Name of the selfip
        :param pulumi.Input[_builtins.str] vlan: Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] port_lockdowns: Specifies the port lockdown, defaults to `Allow None` if not specified.
        :param pulumi.Input[_builtins.str] traffic_group: Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "vlan", vlan)
        if port_lockdowns is not None:
            pulumi.set(__self__, "port_lockdowns", port_lockdowns)
        if traffic_group is not None:
            pulumi.set(__self__, "traffic_group", traffic_group)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Input[_builtins.str]:
        """
        The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the selfip
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "vlan", value)

    @_builtins.property
    @pulumi.getter(name="portLockdowns")
    def port_lockdowns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies the port lockdown, defaults to `Allow None` if not specified.
        """
        return pulumi.get(self, "port_lockdowns")

    @port_lockdowns.setter
    def port_lockdowns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "port_lockdowns", value)

    @_builtins.property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        """
        return pulumi.get(self, "traffic_group")

    @traffic_group.setter
    def traffic_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traffic_group", value)


@pulumi.input_type
class _SelfIpState:
    def __init__(__self__, *,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_lockdowns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SelfIp resources.
        :param pulumi.Input[_builtins.str] ip: The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        :param pulumi.Input[_builtins.str] name: Name of the selfip
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] port_lockdowns: Specifies the port lockdown, defaults to `Allow None` if not specified.
        :param pulumi.Input[_builtins.str] traffic_group: Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        :param pulumi.Input[_builtins.str] vlan: Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        """
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_lockdowns is not None:
            pulumi.set(__self__, "port_lockdowns", port_lockdowns)
        if traffic_group is not None:
            pulumi.set(__self__, "traffic_group", traffic_group)
        if vlan is not None:
            pulumi.set(__self__, "vlan", vlan)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the selfip
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="portLockdowns")
    def port_lockdowns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies the port lockdown, defaults to `Allow None` if not specified.
        """
        return pulumi.get(self, "port_lockdowns")

    @port_lockdowns.setter
    def port_lockdowns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "port_lockdowns", value)

    @_builtins.property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        """
        return pulumi.get(self, "traffic_group")

    @traffic_group.setter
    def traffic_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traffic_group", value)

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vlan", value)


@pulumi.type_token("f5bigip:net/selfIp:SelfIp")
class SelfIp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_lockdowns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `net.SelfIp` Manages a selfip configuration

        Resource should be named with their `full path`. The full path is the combination of the `partition + name of the resource`, for example `/Common/my-selfip`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vlan1 = f5bigip.net.Vlan("vlan1",
            name="/Common/Internal",
            tag=101,
            interfaces=[{
                "vlanport": "1.2",
                "tagged": False,
            }])
        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1/24",
            vlan="/Common/internal",
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```
        ### Example usage with `port_lockdown`

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1/24",
            vlan="/Common/internal",
            traffic_group="traffic-group-1",
            port_lockdowns=[
                "tcp:4040",
                "udp:5050",
                "egp:0",
            ],
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```

        ### Example usage with `port_lockdown` set to `["none"]`

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1/24",
            vlan="/Common/internal",
            traffic_group="traffic-group-1",
            port_lockdowns=["none"],
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```

        ### Example usage with route domain embedded in the `ip`

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1%4/24",
            vlan="/Common/internal",
            traffic_group="traffic-group-1",
            port_lockdowns=["none"],
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] ip: The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        :param pulumi.Input[_builtins.str] name: Name of the selfip
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] port_lockdowns: Specifies the port lockdown, defaults to `Allow None` if not specified.
        :param pulumi.Input[_builtins.str] traffic_group: Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        :param pulumi.Input[_builtins.str] vlan: Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SelfIpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `net.SelfIp` Manages a selfip configuration

        Resource should be named with their `full path`. The full path is the combination of the `partition + name of the resource`, for example `/Common/my-selfip`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        vlan1 = f5bigip.net.Vlan("vlan1",
            name="/Common/Internal",
            tag=101,
            interfaces=[{
                "vlanport": "1.2",
                "tagged": False,
            }])
        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1/24",
            vlan="/Common/internal",
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```
        ### Example usage with `port_lockdown`

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1/24",
            vlan="/Common/internal",
            traffic_group="traffic-group-1",
            port_lockdowns=[
                "tcp:4040",
                "udp:5050",
                "egp:0",
            ],
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```

        ### Example usage with `port_lockdown` set to `["none"]`

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1/24",
            vlan="/Common/internal",
            traffic_group="traffic-group-1",
            port_lockdowns=["none"],
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```

        ### Example usage with route domain embedded in the `ip`

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        selfip1 = f5bigip.net.SelfIp("selfip1",
            name="/Common/internalselfIP",
            ip="11.1.1.1%4/24",
            vlan="/Common/internal",
            traffic_group="traffic-group-1",
            port_lockdowns=["none"],
            opts = pulumi.ResourceOptions(depends_on=[vlan1]))
        ```

        :param str resource_name: The name of the resource.
        :param SelfIpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SelfIpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_lockdowns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SelfIpArgs.__new__(SelfIpArgs)

            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["port_lockdowns"] = port_lockdowns
            __props__.__dict__["traffic_group"] = traffic_group
            if vlan is None and not opts.urn:
                raise TypeError("Missing required property 'vlan'")
            __props__.__dict__["vlan"] = vlan
        super(SelfIp, __self__).__init__(
            'f5bigip:net/selfIp:SelfIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ip: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port_lockdowns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            traffic_group: Optional[pulumi.Input[_builtins.str]] = None,
            vlan: Optional[pulumi.Input[_builtins.str]] = None) -> 'SelfIp':
        """
        Get an existing SelfIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] ip: The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        :param pulumi.Input[_builtins.str] name: Name of the selfip
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] port_lockdowns: Specifies the port lockdown, defaults to `Allow None` if not specified.
        :param pulumi.Input[_builtins.str] traffic_group: Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        :param pulumi.Input[_builtins.str] vlan: Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SelfIpState.__new__(_SelfIpState)

        __props__.__dict__["ip"] = ip
        __props__.__dict__["name"] = name
        __props__.__dict__["port_lockdowns"] = port_lockdowns
        __props__.__dict__["traffic_group"] = traffic_group
        __props__.__dict__["vlan"] = vlan
        return SelfIp(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Output[_builtins.str]:
        """
        The Self IP's address and netmask. The IP address could also contain the route domain, e.g. `10.12.13.14%4/24`.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the selfip
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="portLockdowns")
    def port_lockdowns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Specifies the port lockdown, defaults to `Allow None` if not specified.
        """
        return pulumi.get(self, "port_lockdowns")

    @_builtins.property
    @pulumi.getter(name="trafficGroup")
    def traffic_group(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        """
        return pulumi.get(self, "traffic_group")

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
        """
        return pulumi.get(self, "vlan")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAs3DeviceInformationResult',
    'AwaitableGetAs3DeviceInformationResult',
    'get_as3_device_information',
    'get_as3_device_information_output',
]

@pulumi.output_type
class GetAs3DeviceInformationResult:
    """
    A collection of values returned by getAs3DeviceInformation.
    """
    def __init__(__self__, applications=None, as3_json=None, id=None, tenant=None):
        if applications and not isinstance(applications, list):
            raise TypeError("Expected argument 'applications' to be a list")
        pulumi.set(__self__, "applications", applications)
        if as3_json and not isinstance(as3_json, str):
            raise TypeError("Expected argument 'as3_json' to be a str")
        pulumi.set(__self__, "as3_json", as3_json)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if tenant and not isinstance(tenant, str):
            raise TypeError("Expected argument 'tenant' to be a str")
        pulumi.set(__self__, "tenant", tenant)

    @_builtins.property
    @pulumi.getter
    def applications(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "applications")

    @_builtins.property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> _builtins.str:
        return pulumi.get(self, "as3_json")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def tenant(self) -> _builtins.str:
        return pulumi.get(self, "tenant")


class AwaitableGetAs3DeviceInformationResult(GetAs3DeviceInformationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAs3DeviceInformationResult(
            applications=self.applications,
            as3_json=self.as3_json,
            id=self.id,
            tenant=self.tenant)


def get_as3_device_information(applications: Optional[Sequence[_builtins.str]] = None,
                               tenant: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAs3DeviceInformationResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['applications'] = applications
    __args__['tenant'] = tenant
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:index/getAs3DeviceInformation:getAs3DeviceInformation', __args__, opts=opts, typ=GetAs3DeviceInformationResult).value

    return AwaitableGetAs3DeviceInformationResult(
        applications=pulumi.get(__ret__, 'applications'),
        as3_json=pulumi.get(__ret__, 'as3_json'),
        id=pulumi.get(__ret__, 'id'),
        tenant=pulumi.get(__ret__, 'tenant'))
def get_as3_device_information_output(applications: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                      tenant: Optional[pulumi.Input[_builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAs3DeviceInformationResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['applications'] = applications
    __args__['tenant'] = tenant
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:index/getAs3DeviceInformation:getAs3DeviceInformation', __args__, opts=opts, typ=GetAs3DeviceInformationResult)
    return __ret__.apply(lambda __response__: GetAs3DeviceInformationResult(
        applications=pulumi.get(__response__, 'applications'),
        as3_json=pulumi.get(__response__, 'as3_json'),
        id=pulumi.get(__response__, 'id'),
        tenant=pulumi.get(__response__, 'tenant')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProfileFastL4Args', 'ProfileFastL4']

@pulumi.input_type
class ProfileFastL4Args:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 client_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 explicitflow_migration: Optional[pulumi.Input[_builtins.str]] = None,
                 hardware_syncookie: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toclient: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toserver: Optional[pulumi.Input[_builtins.str]] = None,
                 keepalive_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 late_binding: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_close: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_initiation: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_windowsize: Optional[pulumi.Input[_builtins.int]] = None,
                 tcp_handshake_timeout: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProfileFastL4 resource.
        :param pulumi.Input[_builtins.str] name: Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        :param pulumi.Input[_builtins.int] client_timeout: Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[_builtins.str] explicitflow_migration: Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        :param pulumi.Input[_builtins.str] hardware_syncookie: Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        :param pulumi.Input[_builtins.str] idle_timeout: Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        :param pulumi.Input[_builtins.str] iptos_toclient: Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] iptos_toserver: Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        :param pulumi.Input[_builtins.str] late_binding: Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        :param pulumi.Input[_builtins.str] loose_close: Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        :param pulumi.Input[_builtins.str] loose_initiation: Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        :param pulumi.Input[_builtins.str] partition: name of partition
        :param pulumi.Input[_builtins.int] receive_windowsize: Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        :param pulumi.Input[_builtins.str] tcp_handshake_timeout: Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        pulumi.set(__self__, "name", name)
        if client_timeout is not None:
            pulumi.set(__self__, "client_timeout", client_timeout)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if explicitflow_migration is not None:
            pulumi.set(__self__, "explicitflow_migration", explicitflow_migration)
        if hardware_syncookie is not None:
            pulumi.set(__self__, "hardware_syncookie", hardware_syncookie)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if iptos_toclient is not None:
            pulumi.set(__self__, "iptos_toclient", iptos_toclient)
        if iptos_toserver is not None:
            pulumi.set(__self__, "iptos_toserver", iptos_toserver)
        if keepalive_interval is not None:
            pulumi.set(__self__, "keepalive_interval", keepalive_interval)
        if late_binding is not None:
            pulumi.set(__self__, "late_binding", late_binding)
        if loose_close is not None:
            pulumi.set(__self__, "loose_close", loose_close)
        if loose_initiation is not None:
            pulumi.set(__self__, "loose_initiation", loose_initiation)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if receive_windowsize is not None:
            pulumi.set(__self__, "receive_windowsize", receive_windowsize)
        if tcp_handshake_timeout is not None:
            pulumi.set(__self__, "tcp_handshake_timeout", tcp_handshake_timeout)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="clientTimeout")
    def client_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        """
        return pulumi.get(self, "client_timeout")

    @client_timeout.setter
    def client_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "client_timeout", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter(name="explicitflowMigration")
    def explicitflow_migration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        """
        return pulumi.get(self, "explicitflow_migration")

    @explicitflow_migration.setter
    def explicitflow_migration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "explicitflow_migration", value)

    @_builtins.property
    @pulumi.getter(name="hardwareSyncookie")
    def hardware_syncookie(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        """
        return pulumi.get(self, "hardware_syncookie")

    @hardware_syncookie.setter
    def hardware_syncookie(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hardware_syncookie", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        """
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "idle_timeout", value)

    @_builtins.property
    @pulumi.getter(name="iptosToclient")
    def iptos_toclient(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        """
        return pulumi.get(self, "iptos_toclient")

    @iptos_toclient.setter
    def iptos_toclient(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iptos_toclient", value)

    @_builtins.property
    @pulumi.getter(name="iptosToserver")
    def iptos_toserver(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        """
        return pulumi.get(self, "iptos_toserver")

    @iptos_toserver.setter
    def iptos_toserver(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iptos_toserver", value)

    @_builtins.property
    @pulumi.getter(name="keepaliveInterval")
    def keepalive_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        """
        return pulumi.get(self, "keepalive_interval")

    @keepalive_interval.setter
    def keepalive_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "keepalive_interval", value)

    @_builtins.property
    @pulumi.getter(name="lateBinding")
    def late_binding(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        """
        return pulumi.get(self, "late_binding")

    @late_binding.setter
    def late_binding(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "late_binding", value)

    @_builtins.property
    @pulumi.getter(name="looseClose")
    def loose_close(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        """
        return pulumi.get(self, "loose_close")

    @loose_close.setter
    def loose_close(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "loose_close", value)

    @_builtins.property
    @pulumi.getter(name="looseInitiation")
    def loose_initiation(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        """
        return pulumi.get(self, "loose_initiation")

    @loose_initiation.setter
    def loose_initiation(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "loose_initiation", value)

    @_builtins.property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of partition
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "partition", value)

    @_builtins.property
    @pulumi.getter(name="receiveWindowsize")
    def receive_windowsize(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        """
        return pulumi.get(self, "receive_windowsize")

    @receive_windowsize.setter
    def receive_windowsize(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "receive_windowsize", value)

    @_builtins.property
    @pulumi.getter(name="tcpHandshakeTimeout")
    def tcp_handshake_timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        return pulumi.get(self, "tcp_handshake_timeout")

    @tcp_handshake_timeout.setter
    def tcp_handshake_timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tcp_handshake_timeout", value)


@pulumi.input_type
class _ProfileFastL4State:
    def __init__(__self__, *,
                 client_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 explicitflow_migration: Optional[pulumi.Input[_builtins.str]] = None,
                 hardware_syncookie: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toclient: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toserver: Optional[pulumi.Input[_builtins.str]] = None,
                 keepalive_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 late_binding: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_close: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_initiation: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_windowsize: Optional[pulumi.Input[_builtins.int]] = None,
                 tcp_handshake_timeout: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProfileFastL4 resources.
        :param pulumi.Input[_builtins.int] client_timeout: Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[_builtins.str] explicitflow_migration: Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        :param pulumi.Input[_builtins.str] hardware_syncookie: Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        :param pulumi.Input[_builtins.str] idle_timeout: Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        :param pulumi.Input[_builtins.str] iptos_toclient: Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] iptos_toserver: Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        :param pulumi.Input[_builtins.str] late_binding: Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        :param pulumi.Input[_builtins.str] loose_close: Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        :param pulumi.Input[_builtins.str] loose_initiation: Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        :param pulumi.Input[_builtins.str] name: Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        :param pulumi.Input[_builtins.str] partition: name of partition
        :param pulumi.Input[_builtins.int] receive_windowsize: Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        :param pulumi.Input[_builtins.str] tcp_handshake_timeout: Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        if client_timeout is not None:
            pulumi.set(__self__, "client_timeout", client_timeout)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if explicitflow_migration is not None:
            pulumi.set(__self__, "explicitflow_migration", explicitflow_migration)
        if hardware_syncookie is not None:
            pulumi.set(__self__, "hardware_syncookie", hardware_syncookie)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if iptos_toclient is not None:
            pulumi.set(__self__, "iptos_toclient", iptos_toclient)
        if iptos_toserver is not None:
            pulumi.set(__self__, "iptos_toserver", iptos_toserver)
        if keepalive_interval is not None:
            pulumi.set(__self__, "keepalive_interval", keepalive_interval)
        if late_binding is not None:
            pulumi.set(__self__, "late_binding", late_binding)
        if loose_close is not None:
            pulumi.set(__self__, "loose_close", loose_close)
        if loose_initiation is not None:
            pulumi.set(__self__, "loose_initiation", loose_initiation)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if receive_windowsize is not None:
            pulumi.set(__self__, "receive_windowsize", receive_windowsize)
        if tcp_handshake_timeout is not None:
            pulumi.set(__self__, "tcp_handshake_timeout", tcp_handshake_timeout)

    @_builtins.property
    @pulumi.getter(name="clientTimeout")
    def client_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        """
        return pulumi.get(self, "client_timeout")

    @client_timeout.setter
    def client_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "client_timeout", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter(name="explicitflowMigration")
    def explicitflow_migration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        """
        return pulumi.get(self, "explicitflow_migration")

    @explicitflow_migration.setter
    def explicitflow_migration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "explicitflow_migration", value)

    @_builtins.property
    @pulumi.getter(name="hardwareSyncookie")
    def hardware_syncookie(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        """
        return pulumi.get(self, "hardware_syncookie")

    @hardware_syncookie.setter
    def hardware_syncookie(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hardware_syncookie", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        """
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "idle_timeout", value)

    @_builtins.property
    @pulumi.getter(name="iptosToclient")
    def iptos_toclient(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        """
        return pulumi.get(self, "iptos_toclient")

    @iptos_toclient.setter
    def iptos_toclient(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iptos_toclient", value)

    @_builtins.property
    @pulumi.getter(name="iptosToserver")
    def iptos_toserver(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        """
        return pulumi.get(self, "iptos_toserver")

    @iptos_toserver.setter
    def iptos_toserver(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iptos_toserver", value)

    @_builtins.property
    @pulumi.getter(name="keepaliveInterval")
    def keepalive_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        """
        return pulumi.get(self, "keepalive_interval")

    @keepalive_interval.setter
    def keepalive_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "keepalive_interval", value)

    @_builtins.property
    @pulumi.getter(name="lateBinding")
    def late_binding(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        """
        return pulumi.get(self, "late_binding")

    @late_binding.setter
    def late_binding(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "late_binding", value)

    @_builtins.property
    @pulumi.getter(name="looseClose")
    def loose_close(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        """
        return pulumi.get(self, "loose_close")

    @loose_close.setter
    def loose_close(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "loose_close", value)

    @_builtins.property
    @pulumi.getter(name="looseInitiation")
    def loose_initiation(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        """
        return pulumi.get(self, "loose_initiation")

    @loose_initiation.setter
    def loose_initiation(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "loose_initiation", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of partition
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "partition", value)

    @_builtins.property
    @pulumi.getter(name="receiveWindowsize")
    def receive_windowsize(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        """
        return pulumi.get(self, "receive_windowsize")

    @receive_windowsize.setter
    def receive_windowsize(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "receive_windowsize", value)

    @_builtins.property
    @pulumi.getter(name="tcpHandshakeTimeout")
    def tcp_handshake_timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        return pulumi.get(self, "tcp_handshake_timeout")

    @tcp_handshake_timeout.setter
    def tcp_handshake_timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tcp_handshake_timeout", value)


@pulumi.type_token("f5bigip:ltm/profileFastL4:ProfileFastL4")
class ProfileFastL4(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 explicitflow_migration: Optional[pulumi.Input[_builtins.str]] = None,
                 hardware_syncookie: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toclient: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toserver: Optional[pulumi.Input[_builtins.str]] = None,
                 keepalive_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 late_binding: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_close: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_initiation: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_windowsize: Optional[pulumi.Input[_builtins.int]] = None,
                 tcp_handshake_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `ltm.ProfileFastL4` Configures a custom LTM fastL4 profile for use by health checks.

        Resources should be named with their `full path`. The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        profile_fastl4 = f5bigip.ltm.ProfileFastL4("profile_fastl4",
            name="/Common/sjfastl4profile",
            defaults_from="/Common/fastL4",
            client_timeout=40,
            explicitflow_migration="enabled",
            hardware_syncookie="enabled",
            idle_timeout="200",
            iptos_toclient="pass-through",
            iptos_toserver="pass-through",
            keepalive_interval="disabled")
        ```

        ## Import

        BIG-IP LTM fastl4 profiles can be imported using the `name`, e.g.

        ```sh
        $ pulumi import f5bigip:ltm/profileFastL4:ProfileFastL4 test-fastl4 /Common/test-fastl4
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] client_timeout: Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[_builtins.str] explicitflow_migration: Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        :param pulumi.Input[_builtins.str] hardware_syncookie: Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        :param pulumi.Input[_builtins.str] idle_timeout: Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        :param pulumi.Input[_builtins.str] iptos_toclient: Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] iptos_toserver: Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        :param pulumi.Input[_builtins.str] late_binding: Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        :param pulumi.Input[_builtins.str] loose_close: Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        :param pulumi.Input[_builtins.str] loose_initiation: Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        :param pulumi.Input[_builtins.str] name: Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        :param pulumi.Input[_builtins.str] partition: name of partition
        :param pulumi.Input[_builtins.int] receive_windowsize: Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        :param pulumi.Input[_builtins.str] tcp_handshake_timeout: Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileFastL4Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileFastL4` Configures a custom LTM fastL4 profile for use by health checks.

        Resources should be named with their `full path`. The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        profile_fastl4 = f5bigip.ltm.ProfileFastL4("profile_fastl4",
            name="/Common/sjfastl4profile",
            defaults_from="/Common/fastL4",
            client_timeout=40,
            explicitflow_migration="enabled",
            hardware_syncookie="enabled",
            idle_timeout="200",
            iptos_toclient="pass-through",
            iptos_toserver="pass-through",
            keepalive_interval="disabled")
        ```

        ## Import

        BIG-IP LTM fastl4 profiles can be imported using the `name`, e.g.

        ```sh
        $ pulumi import f5bigip:ltm/profileFastL4:ProfileFastL4 test-fastl4 /Common/test-fastl4
        ```

        :param str resource_name: The name of the resource.
        :param ProfileFastL4Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileFastL4Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 explicitflow_migration: Optional[pulumi.Input[_builtins.str]] = None,
                 hardware_syncookie: Optional[pulumi.Input[_builtins.str]] = None,
                 idle_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toclient: Optional[pulumi.Input[_builtins.str]] = None,
                 iptos_toserver: Optional[pulumi.Input[_builtins.str]] = None,
                 keepalive_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 late_binding: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_close: Optional[pulumi.Input[_builtins.str]] = None,
                 loose_initiation: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_windowsize: Optional[pulumi.Input[_builtins.int]] = None,
                 tcp_handshake_timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileFastL4Args.__new__(ProfileFastL4Args)

            __props__.__dict__["client_timeout"] = client_timeout
            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["explicitflow_migration"] = explicitflow_migration
            __props__.__dict__["hardware_syncookie"] = hardware_syncookie
            __props__.__dict__["idle_timeout"] = idle_timeout
            __props__.__dict__["iptos_toclient"] = iptos_toclient
            __props__.__dict__["iptos_toserver"] = iptos_toserver
            __props__.__dict__["keepalive_interval"] = keepalive_interval
            __props__.__dict__["late_binding"] = late_binding
            __props__.__dict__["loose_close"] = loose_close
            __props__.__dict__["loose_initiation"] = loose_initiation
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            __props__.__dict__["receive_windowsize"] = receive_windowsize
            __props__.__dict__["tcp_handshake_timeout"] = tcp_handshake_timeout
        super(ProfileFastL4, __self__).__init__(
            'f5bigip:ltm/profileFastL4:ProfileFastL4',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
            explicitflow_migration: Optional[pulumi.Input[_builtins.str]] = None,
            hardware_syncookie: Optional[pulumi.Input[_builtins.str]] = None,
            idle_timeout: Optional[pulumi.Input[_builtins.str]] = None,
            iptos_toclient: Optional[pulumi.Input[_builtins.str]] = None,
            iptos_toserver: Optional[pulumi.Input[_builtins.str]] = None,
            keepalive_interval: Optional[pulumi.Input[_builtins.str]] = None,
            late_binding: Optional[pulumi.Input[_builtins.str]] = None,
            loose_close: Optional[pulumi.Input[_builtins.str]] = None,
            loose_initiation: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            partition: Optional[pulumi.Input[_builtins.str]] = None,
            receive_windowsize: Optional[pulumi.Input[_builtins.int]] = None,
            tcp_handshake_timeout: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProfileFastL4':
        """
        Get an existing ProfileFastL4 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] client_timeout: Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[_builtins.str] explicitflow_migration: Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        :param pulumi.Input[_builtins.str] hardware_syncookie: Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        :param pulumi.Input[_builtins.str] idle_timeout: Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        :param pulumi.Input[_builtins.str] iptos_toclient: Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] iptos_toserver: Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        :param pulumi.Input[_builtins.str] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        :param pulumi.Input[_builtins.str] late_binding: Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        :param pulumi.Input[_builtins.str] loose_close: Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        :param pulumi.Input[_builtins.str] loose_initiation: Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        :param pulumi.Input[_builtins.str] name: Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        :param pulumi.Input[_builtins.str] partition: name of partition
        :param pulumi.Input[_builtins.int] receive_windowsize: Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        :param pulumi.Input[_builtins.str] tcp_handshake_timeout: Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileFastL4State.__new__(_ProfileFastL4State)

        __props__.__dict__["client_timeout"] = client_timeout
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["explicitflow_migration"] = explicitflow_migration
        __props__.__dict__["hardware_syncookie"] = hardware_syncookie
        __props__.__dict__["idle_timeout"] = idle_timeout
        __props__.__dict__["iptos_toclient"] = iptos_toclient
        __props__.__dict__["iptos_toserver"] = iptos_toserver
        __props__.__dict__["keepalive_interval"] = keepalive_interval
        __props__.__dict__["late_binding"] = late_binding
        __props__.__dict__["loose_close"] = loose_close
        __props__.__dict__["loose_initiation"] = loose_initiation
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["receive_windowsize"] = receive_windowsize
        __props__.__dict__["tcp_handshake_timeout"] = tcp_handshake_timeout
        return ProfileFastL4(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientTimeout")
    def client_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies late binding client timeout in seconds. This setting specifies the number of seconds allowed for a client to transmit enough data to select a server when late binding is enabled. If it expires timeout-recovery mode will dictate what action to take.
        """
        return pulumi.get(self, "client_timeout")

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @_builtins.property
    @pulumi.getter(name="explicitflowMigration")
    def explicitflow_migration(self) -> pulumi.Output[_builtins.str]:
        """
        Enables or disables late binding explicit flow migration that allows iRules to control when flows move from software to hardware. Explicit flow migration is disabled by default hence BIG-IP automatically migrates flows from software to hardware.
        """
        return pulumi.get(self, "explicitflow_migration")

    @_builtins.property
    @pulumi.getter(name="hardwareSyncookie")
    def hardware_syncookie(self) -> pulumi.Output[_builtins.str]:
        """
        Enables or disables hardware SYN cookie support when PVA10 is present on the system. Note that when you set the hardware syncookie option to enabled, you may also want to set the following bigdb database variables using the "/sys modify db" command, based on your requirements: pva.SynCookies.Full.ConnectionThreshold (default: 500000), pva.SynCookies.Assist.ConnectionThreshold (default: 500000) pva.SynCookies.ClientWindow (default: 0). The default value is disabled.
        """
        return pulumi.get(self, "hardware_syncookie")

    @_builtins.property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies an idle timeout in seconds. This setting specifies the number of seconds that a connection is idle before the connection is eligible for deletion.When you specify an idle timeout for the Fast L4 profile, the value must be greater than the bigdb database variable Pva.Scrub time in msec for it to work properly.The default value is 300 seconds.
        """
        return pulumi.get(self, "idle_timeout")

    @_builtins.property
    @pulumi.getter(name="iptosToclient")
    def iptos_toclient(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies an IP ToS number for the client side. This option specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to clients. The default value is 65535 (pass-through), which indicates, do not modify.
        """
        return pulumi.get(self, "iptos_toclient")

    @_builtins.property
    @pulumi.getter(name="iptosToserver")
    def iptos_toserver(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies an IP ToS number for the server side. This setting specifies the Type of Service level that the traffic management system assigns to IP packets when sending them to servers. The default value is 65535 (pass-through), which indicates, do not modify.
        """
        return pulumi.get(self, "iptos_toserver")

    @_builtins.property
    @pulumi.getter(name="keepaliveInterval")
    def keepalive_interval(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the keep alive probe interval, in seconds. The default value is disabled (0 seconds).
        """
        return pulumi.get(self, "keepalive_interval")

    @_builtins.property
    @pulumi.getter(name="lateBinding")
    def late_binding(self) -> pulumi.Output[_builtins.str]:
        """
        Enables intelligent selection of a back-end server or pool, using an iRule to make the selection. The default is `disabled`.
        """
        return pulumi.get(self, "late_binding")

    @_builtins.property
    @pulumi.getter(name="looseClose")
    def loose_close(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies, when checked (enabled), that the system closes a loosely-initiated connection when the system receives the first FIN packet from either the client or the server. The default is disabled.
        """
        return pulumi.get(self, "loose_close")

    @_builtins.property
    @pulumi.getter(name="looseInitiation")
    def loose_initiation(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies, when checked (enabled), that the system initializes a connection when it receives any TCP packet, rather that requiring a SYN packet for connection initiation. The default is disabled. We recommend that if you enable the Loose Initiation option, you also enable the Loose Close option.
        """
        return pulumi.get(self, "loose_initiation")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the LTM fastL4 Profile.The full path is the combination of the `partition + name` of the resource (For example `/Common/my-fastl4profile`) or  `partition + directory + name` of the resource  (example: `/Common/test/my-fastl4profile`)
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def partition(self) -> pulumi.Output[_builtins.str]:
        """
        name of partition
        """
        return pulumi.get(self, "partition")

    @_builtins.property
    @pulumi.getter(name="receiveWindowsize")
    def receive_windowsize(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies the amount of data the BIG-IP system can accept without acknowledging the server. The default is 0 (zero).
        """
        return pulumi.get(self, "receive_windowsize")

    @_builtins.property
    @pulumi.getter(name="tcpHandshakeTimeout")
    def tcp_handshake_timeout(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the acceptable duration for a TCP handshake, that is, the maximum idle time between a client synchronization (SYN) and a client acknowledgment (ACK).The default is `5 seconds`.
        """
        return pulumi.get(self, "tcp_handshake_timeout")

